"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const tools_1 = require("../../../tools");
const utils_1 = require("../../../utils");
const defaults_1 = require("../../defaults");
function parse(context) {
    const emailsFolder = path_1.default.join(context.filePath, tools_1.constants.EMAIL_TEMPLATES_DIRECTORY);
    if (!(0, utils_1.existsMustBeDir)(emailsFolder))
        return { emailProvider: null }; // Skip
    const providerFile = path_1.default.join(emailsFolder, 'provider.json');
    if ((0, utils_1.isFile)(providerFile)) {
        return {
            emailProvider: (0, utils_1.loadJSON)(providerFile, {
                mappings: context.mappings,
                disableKeywordReplacement: context.disableKeywordReplacement,
            }),
        };
    }
    return { emailProvider: null };
}
function dump(context) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!context.assets.emailProvider)
            return; // Skip, nothing to dump
        const emailProvider = (() => {
            var _a;
            const excludedDefaults = ((_a = context.assets.exclude) === null || _a === void 0 ? void 0 : _a.defaults) || [];
            if (!excludedDefaults.includes('emailProvider')) {
                // Add placeholder for credentials as they cannot be exported
                return (0, defaults_1.emailProviderDefaults)(context.assets.emailProvider);
            }
            return context.assets.emailProvider;
        })();
        const emailsFolder = path_1.default.join(context.filePath, tools_1.constants.EMAIL_TEMPLATES_DIRECTORY);
        fs_extra_1.default.ensureDirSync(emailsFolder);
        const emailProviderFile = path_1.default.join(emailsFolder, 'provider.json');
        (0, utils_1.dumpJSON)(emailProviderFile, emailProvider);
    });
}
const emailProviderHandler = {
    parse,
    dump,
};
exports.default = emailProviderHandler;
//# sourceMappingURL=emailProvider.js.map