"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const tools_1 = require("../../../tools");
const utils_1 = require("../../../utils");
const logger_1 = __importDefault(require("../../../logger"));
function parse(context) {
    const triggersFolder = path_1.default.join(context.filePath, tools_1.constants.TRIGGERS_DIRECTORY);
    if (!(0, utils_1.existsMustBeDir)(triggersFolder))
        return { triggers: null }; // Skip
    const files = (0, utils_1.getFiles)(triggersFolder, ['.json']);
    const triggers = Object.assign({}, (0, utils_1.loadJSON)(files[0], {
        mappings: context.mappings,
        disableKeywordReplacement: context.disableKeywordReplacement,
    }));
    return { triggers };
}
function dump(context) {
    return __awaiter(this, void 0, void 0, function* () {
        const { triggers } = context.assets;
        if (!triggers)
            return;
        // Create triggers folder
        const triggersFolder = path_1.default.join(context.filePath, tools_1.constants.TRIGGERS_DIRECTORY);
        fs_extra_1.default.ensureDirSync(triggersFolder);
        const triggerFile = path_1.default.join(triggersFolder, 'triggers.json');
        logger_1.default.info(`Writing ${triggerFile}`);
        fs_extra_1.default.writeFileSync(triggerFile, JSON.stringify(triggers, null, 2));
    });
}
const triggersHandler = {
    parse,
    dump,
};
exports.default = triggersHandler;
//# sourceMappingURL=triggers.js.map