"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.schema = void 0;
const lodash_1 = require("lodash");
const default_1 = __importStar(require("./default"));
const constants_1 = __importDefault(require("../../constants"));
const logger_1 = __importDefault(require("../../../logger"));
exports.schema = {
    type: 'array',
    items: {
        type: 'object',
        properties: {
            name: { type: 'string' },
            app_id: { type: 'string', enum: constants_1.default.CONNECTION_APP_ID },
            environment: { type: 'string' },
            setup: { type: 'object' },
            account_name: { type: 'string' },
            ready: { type: 'boolean' },
        },
        required: ['name', 'app_id'],
    },
    additionalProperties: false,
};
class FlowVaultHandler extends default_1.default {
    constructor(options) {
        super(Object.assign(Object.assign({}, options), { type: 'flowVaultConnections', id: 'id', stripCreateFields: ['created_at', 'updated_at', 'refreshed_at', 'fingerprint', 'ready'], stripUpdateFields: ['created_at', 'updated_at', 'refreshed_at', 'fingerprint', 'ready'] }));
    }
    getType() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.existing) {
                return this.existing;
            }
            this.existing = yield this.getAllFlowConnections();
            return this.existing;
        });
    }
    processChanges(assets) {
        return __awaiter(this, void 0, void 0, function* () {
            const { flowVaultConnections } = assets;
            // Do nothing if not set
            if (!flowVaultConnections)
                return;
            const { del, update, create } = yield this.calcChanges(assets);
            logger_1.default.debug(`Start processChanges for flow vault connections [delete:${del.length}] [update:${update.length}], [create:${create.length}]`);
            const changes = [{ del: del }, { create: create }, { update: update }];
            yield Promise.all(changes.map((change) => __awaiter(this, void 0, void 0, function* () {
                switch (true) {
                    case change.del && change.del.length > 0:
                        yield this.deleteVaultConnections(change.del || []);
                        break;
                    case change.create && change.create.length > 0:
                        yield this.createVaultConnections(change.create);
                        break;
                    case change.update && change.update.length > 0:
                        if (change.update)
                            yield this.updateVaultConnections(change.update);
                        break;
                    default:
                        break;
                }
            })));
        });
    }
    getAllFlowConnections() {
        return __awaiter(this, void 0, void 0, function* () {
            const allFlowConnections = [];
            // paginate without paginate<T> helper as this is not getAll but getAllConnections
            // paginate through all flow connections
            let page = 0;
            while (true) {
                const { data: { connections, total }, } = yield this.client.flows.getAllConnections({
                    page: page,
                    per_page: 100,
                    include_totals: true,
                });
                // if we get an unexpected response, break the loop to avoid infinite loop
                if (!(0, lodash_1.isArray)(allFlowConnections) || typeof total !== 'number') {
                    break;
                }
                allFlowConnections.push(...connections);
                page += 1;
                if (allFlowConnections.length === total) {
                    break;
                }
            }
            return allFlowConnections;
        });
    }
    createVaultConnection(conn) {
        return __awaiter(this, void 0, void 0, function* () {
            if ('ready' in conn) {
                delete conn.ready;
            }
            if ('account_name' in conn) {
                delete conn.account_name;
            }
            const { data: created } = yield this.client.flows.createConnection(conn);
            return created;
        });
    }
    createVaultConnections(creates) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.pool
                .addEachTask({
                data: creates || [],
                generator: (item) => this.createVaultConnection(item)
                    .then((data) => {
                    this.didCreate(data);
                    this.created += 1;
                })
                    .catch((err) => {
                    throw new Error(`Problem creating ${this.type} ${this.objString(item)}\n${err}`);
                }),
            })
                .promise();
        });
    }
    updateVaultConnection(conn) {
        return __awaiter(this, void 0, void 0, function* () {
            const { id, name, setup } = conn;
            const params = {
                name,
            };
            if (!(0, lodash_1.isEmpty)(setup)) {
                params.setup = setup;
            }
            const updated = yield this.client.flows.updateConnection({ id: id }, params);
            return updated;
        });
    }
    updateVaultConnections(updates) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.pool
                .addEachTask({
                data: updates || [],
                generator: (item) => this.updateVaultConnection(item)
                    .then((data) => {
                    this.didUpdate(data);
                    this.updated += 1;
                })
                    .catch((err) => {
                    throw new Error(`Problem updating ${this.type} ${this.objString(item)}\n${err}`);
                }),
            })
                .promise();
        });
    }
    deleteVaultConnection(conn) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.flows.deleteConnection({ id: conn.id });
        });
    }
    deleteVaultConnections(data) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.config('AUTH0_ALLOW_DELETE') === 'true' ||
                this.config('AUTH0_ALLOW_DELETE') === true) {
                yield this.client.pool
                    .addEachTask({
                    data: data || [],
                    generator: (item) => this.deleteVaultConnection(item)
                        .then(() => {
                        this.didDelete(item);
                        this.deleted += 1;
                    })
                        .catch((err) => {
                        throw new Error(`Problem deleting ${this.type} ${this.objString(item)}\n${err}`);
                    }),
                })
                    .promise();
            }
            else {
                logger_1.default.warn(`Detected the following flow vault connection should be deleted. Doing so may be destructive.\nYou can enable deletes by setting 'AUTH0_ALLOW_DELETE' to true in the config
      \n${data.map((i) => this.objString(i)).join('\n')}`);
            }
        });
    }
}
exports.default = FlowVaultHandler;
__decorate([
    (0, default_1.order)('50')
], FlowVaultHandler.prototype, "processChanges", null);
//# sourceMappingURL=flowVaultConnections.js.map