"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.schema = void 0;
const lodash_1 = require("lodash");
const dot_prop_1 = __importDefault(require("dot-prop"));
const default_1 = __importStar(require("./default"));
const client_1 = require("../client");
const logger_1 = __importDefault(require("../../../logger"));
const utils_1 = require("../../../utils");
exports.schema = {
    type: 'array',
    items: {
        type: 'object',
        properties: {
            name: { type: 'string' },
            body: { type: 'string' },
        },
        required: ['name'],
    },
    additionalProperties: false,
};
class FlowHandler extends default_1.default {
    constructor(options) {
        super(Object.assign(Object.assign({}, options), { type: 'flows', id: 'id', stripCreateFields: ['created_at', 'updated_at', 'executed_at'], stripUpdateFields: ['created_at', 'updated_at', 'executed_at'] }));
    }
    getType() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.existing) {
                return this.existing;
            }
            const [flows, allFlowConnections] = yield Promise.all([
                (0, client_1.paginate)(this.client.flows.getAll, {
                    paginate: true,
                    include_totals: true,
                }),
                this.getAllFlowConnections(),
            ]);
            const allFlows = yield Promise.all(flows.map((f) => __awaiter(this, void 0, void 0, function* () {
                const { data: flow } = yield this.client.flows.get({ id: f.id });
                return flow;
            })));
            // create a map for id to name from allFlowConnections
            const connectionIdMap = {};
            allFlowConnections.forEach((c) => {
                connectionIdMap[c.id] = c.name;
            });
            this.existing = yield this.formateFlowConnectionId(allFlows, connectionIdMap);
            return this.existing;
        });
    }
    processChanges(assets) {
        const _super = Object.create(null, {
            processChanges: { get: () => super.processChanges }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const { flows } = assets;
            // Do nothing if not set
            if (!flows)
                return;
            const allFlowConnections = yield this.getAllFlowConnections();
            // create a map for name to id from allFlowConnections
            const connectionNameMap = {};
            allFlowConnections.forEach((c) => {
                connectionNameMap[c.name] = c.id;
            });
            assets.flows = yield this.pargeFlowConnectionName(flows, connectionNameMap);
            const { del, update, create, conflicts } = yield this.calcChanges(assets);
            const changes = {
                del: del,
                update: update,
                create: create,
                conflicts: conflicts,
            };
            yield _super.processChanges.call(this, assets, Object.assign({}, changes));
        });
    }
    getAllFlowConnections() {
        return __awaiter(this, void 0, void 0, function* () {
            const allFlowConnections = [];
            // paginate without paginate<T> helper as this is not getAll but getAllConnections
            // paginate through all flow connections
            let page = 0;
            while (true) {
                const { data: { connections, total }, } = yield this.client.flows.getAllConnections({
                    page: page,
                    per_page: 100,
                    include_totals: true,
                });
                // if we get an unexpected response, break the loop to avoid infinite loop
                if (!(0, lodash_1.isArray)(allFlowConnections) || typeof total !== 'number') {
                    break;
                }
                allFlowConnections.push(...connections);
                page += 1;
                if (allFlowConnections.length === total) {
                    break;
                }
            }
            return allFlowConnections;
        });
    }
    formateFlowConnectionId(flows, connectionIdMap) {
        return __awaiter(this, void 0, void 0, function* () {
            // replace connection_id with flow connection names
            yield Promise.all(flows.map((flow) => __awaiter(this, void 0, void 0, function* () {
                const flowConnetions = (0, utils_1.findKeyPathWithValue)(flow, 'connection_id');
                yield Promise.all(flowConnetions.map((f) => __awaiter(this, void 0, void 0, function* () {
                    const connectionId = (dot_prop_1.default.get(flow, f.path) || '');
                    const flowConnectionName = connectionIdMap[connectionId];
                    if (!flowConnectionName) {
                        logger_1.default.warn(`Flow connection: ${connectionId} not found for flow:${flow.name}, please verify the flow connection id.`);
                    }
                    else {
                        dot_prop_1.default.set(flow, f.path, flowConnectionName);
                    }
                })));
                return flow;
            })));
            return flows;
        });
    }
    pargeFlowConnectionName(flows, connectionNameMap) {
        return __awaiter(this, void 0, void 0, function* () {
            // replace connection_id with flow connection names
            const parsedFlows = yield Promise.all(flows.map((flow) => __awaiter(this, void 0, void 0, function* () {
                const flowConnetions = (0, utils_1.findKeyPathWithValue)(flow, 'connection_id');
                yield Promise.all(flowConnetions.map((f) => __awaiter(this, void 0, void 0, function* () {
                    const connectionName = (dot_prop_1.default.get(flow, f.path) || '');
                    const flowConnectionId = connectionNameMap[connectionName];
                    if (!flowConnectionId) {
                        logger_1.default.error(`Flow connection: ${flowConnectionId} not found for flow:${flow.name}, please verify the flow connection name.`);
                    }
                    else {
                        dot_prop_1.default.set(flow, f.path, flowConnectionId);
                    }
                })));
                return flow;
            })));
            return parsedFlows;
        });
    }
}
exports.default = FlowHandler;
__decorate([
    (0, default_1.order)('60')
], FlowHandler.prototype, "processChanges", null);
//# sourceMappingURL=flows.js.map