"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.schema = void 0;
const default_1 = __importDefault(require("./default"));
const constants_1 = __importDefault(require("../../constants"));
const utils_1 = require("../../utils");
const mappings = Object.entries(constants_1.default.GUARDIAN_FACTOR_PROVIDERS).reduce((accum, [name, providers]) => {
    providers.forEach((p) => {
        accum.push({ name, provider: p });
    });
    return accum;
}, []);
exports.schema = {
    type: 'array',
    items: {
        type: 'object',
        properties: {
            name: { type: 'string', enum: constants_1.default.GUARDIAN_FACTORS },
            provider: { type: 'string', enum: mappings.map((p) => p.provider) },
        },
        required: ['name', 'provider'],
    },
};
class GuardianFactorProvidersHandler extends default_1.default {
    constructor(options) {
        super(Object.assign(Object.assign({}, options), { type: 'guardianFactorProviders', id: 'name' }));
    }
    getType() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.existing)
                return this.existing;
            try {
                const data = yield Promise.all(mappings.map((m) => __awaiter(this, void 0, void 0, function* () {
                    let provider;
                    // TODO: This is quite a change, needs to be validated for sure.
                    if (m.name === 'phone' && m.provider === 'twilio') {
                        provider = yield this.client.guardian.getPhoneFactorProviderTwilio();
                    }
                    else if (m.name === 'sms' && m.provider === 'twilio') {
                        provider = yield this.client.guardian.getSmsFactorProviderTwilio();
                    }
                    else if (m.name === 'push-notification' && m.provider === 'apns') {
                        provider = yield this.client.guardian.getPushNotificationProviderAPNS();
                    }
                    else if (m.name === 'push-notification' && m.provider === 'sns') {
                        provider = yield this.client.guardian.getPushNotificationProviderSNS();
                    }
                    return Object.assign(Object.assign({}, m), provider.data);
                })));
                // Filter out empty, should have more then 2 keys (name, provider)
                return data.filter((d) => Object.keys(d).length > 2);
            }
            catch (err) {
                if (err.statusCode === 404 || err.statusCode === 501) {
                    return null;
                }
                if ((0, utils_1.isForbiddenFeatureError)(err, this.type)) {
                    return null;
                }
                throw err;
            }
        });
    }
    processChanges(assets) {
        return __awaiter(this, void 0, void 0, function* () {
            // No API to delete or create guardianFactorProviders, we can only update.
            const { guardianFactorProviders } = assets;
            // Do nothing if not set
            if (!guardianFactorProviders || !guardianFactorProviders.length)
                return;
            // Process each factor
            yield Promise.all(guardianFactorProviders.map((factorProvider) => __awaiter(this, void 0, void 0, function* () {
                const { name, provider } = factorProvider, data = __rest(factorProvider, ["name", "provider"]);
                const params = { name: factorProvider.name, provider: factorProvider.provider };
                // TODO: This is quite a change, needs to be validated for sure.
                if (name === 'phone' && provider === 'twilio') {
                    yield this.client.guardian.updatePhoneFactorProviderTwilio(data);
                }
                else if (name === 'sms' && provider === 'twilio') {
                    yield this.client.guardian.setSmsFactorProviderTwilio(data);
                }
                else if (name === 'push-notification' && provider === 'apns') {
                    yield this.client.guardian.updatePushNotificationProviderAPNS(data);
                }
                else if (name === 'push-notification' && provider === 'fcm') {
                    yield this.client.guardian.updatePushNotificationProviderFCM(data);
                }
                else if (name === 'push-notification' && provider === 'sns') {
                    yield this.client.guardian.updatePushNotificationProviderSNS(data);
                }
                this.didUpdate(params);
                this.updated += 1;
            })));
        });
    }
}
exports.default = GuardianFactorProvidersHandler;
//# sourceMappingURL=guardianFactorProviders.js.map