"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.schema = void 0;
const default_1 = __importStar(require("./default"));
const logger_1 = __importDefault(require("../../../logger"));
const TwilioConfigurationSchema = {
    type: 'object',
    required: ['sid', 'delivery_methods'],
    additionalProperties: false,
    properties: {
        default_from: {
            type: 'string',
        },
        mssid: {
            type: 'string',
        },
        sid: {
            type: 'string',
        },
        delivery_methods: {
            type: 'array',
            items: {
                type: 'string',
                enum: ['text', 'voice'],
            },
            minItems: 1,
            uniqueItems: true,
        },
    },
};
const CustomCredentialsSchema = {
    type: 'object',
    additionalProperties: false,
    properties: {},
};
const CustomConfigurationSchema = {
    type: 'object',
    additionalProperties: false,
    required: ['delivery_methods'],
    properties: {
        delivery_methods: {
            type: 'array',
            items: {
                type: 'string',
                enum: ['text', 'voice'],
            },
            minItems: 1,
            uniqueItems: true,
        },
    },
};
const TwilioCredentialsSchema = {
    type: 'object',
    required: ['auth_token'],
    properties: {
        auth_token: {
            type: 'string',
            minLength: 1,
            maxLength: 255,
        },
    },
    additionalProperties: false,
};
exports.schema = {
    type: 'array',
    description: 'List of phone provider configurations',
    items: {
        type: 'object',
        properties: {
            id: {
                type: 'string',
                minLength: 1,
                maxLength: 255,
            },
            name: {
                type: 'string',
                description: 'Name of the phone notification provider',
                enum: ['twilio', 'custom'],
                minLength: 1,
                maxLength: 100,
            },
            disabled: {
                type: 'boolean',
                description: 'Whether the provider is enabled (false) or disabled (true).',
                defaultValue: false,
            },
            configuration: {
                type: 'object',
                anyOf: [TwilioConfigurationSchema, CustomConfigurationSchema],
            },
            credentials: {
                description: 'Provider credentials required to authenticate to the provider.',
                anyOf: [TwilioCredentialsSchema, CustomCredentialsSchema],
            },
        },
        additionalProperties: false,
    },
};
class PhoneProviderHandler extends default_1.default {
    constructor(options) {
        super(Object.assign(Object.assign({}, options), { type: 'phoneProviders', id: 'id' }));
    }
    objString(provider) {
        return super.objString({ name: provider.name, disabled: provider.disabled }); //Que
    }
    getType() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.existing) {
                this.existing = yield this.getPhoneProviders();
            }
            return this.existing;
        });
    }
    getPhoneProviders() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            const { data: response } = yield this.client.branding.getAllPhoneProviders();
            return (_a = response.providers) !== null && _a !== void 0 ? _a : [];
        });
    }
    processChanges(assets) {
        return __awaiter(this, void 0, void 0, function* () {
            const { phoneProviders } = assets;
            // Non-existing section means themes doesn't need to be processed
            if (!phoneProviders)
                return;
            // Empty array means themes should be deleted
            if (phoneProviders.length === 0) {
                yield this.deletePhoneProviders();
            }
            else {
                yield this.updatePhoneProviders(phoneProviders);
            }
        });
    }
    deletePhoneProviders() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.config('AUTH0_ALLOW_DELETE')) {
                return;
            }
            // if phone providers exists we need to delete it
            const currentProviders = yield this.getPhoneProviders();
            if (currentProviders === null || currentProviders.length === 0) {
                return;
            }
            const currentProvider = currentProviders[0];
            yield this.client.branding.deletePhoneProvider({
                id: currentProvider.id,
            });
            this.deleted += 1;
            this.didDelete(currentProvider);
        });
    }
    updatePhoneProviders(phoneProviders) {
        return __awaiter(this, void 0, void 0, function* () {
            if (phoneProviders.length > 1) {
                logger_1.default.warn('Currently only one phone provider is supported per tenant');
            }
            const currentProviders = yield this.getPhoneProviders();
            const providerReqPayload = (() => {
                // Removing id from update and create payloads, otherwise API will error
                // id may be required to handle if `--export_ids=true`
                const payload = phoneProviders[0];
                if (payload && 'id' in payload) {
                    delete payload.id;
                }
                return payload;
            })();
            if (currentProviders === null || currentProviders.length === 0) {
                // if provider does not exist, create it
                this.created += 1;
                yield this.client.branding.configurePhoneProvider(providerReqPayload);
            }
            else {
                const currentProvider = currentProviders[0];
                // if provider exists, overwrite it
                yield this.client.branding.updatePhoneProvider({ id: currentProvider.id }, providerReqPayload);
                this.updated += 1;
                this.didUpdate(phoneProviders[0]);
            }
        });
    }
}
exports.default = PhoneProviderHandler;
__decorate([
    (0, default_1.order)('60')
], PhoneProviderHandler.prototype, "processChanges", null);
//# sourceMappingURL=phoneProvider.js.map