"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.schema = void 0;
const lodash_1 = require("lodash");
const auth0_1 = require("auth0");
const default_1 = __importDefault(require("./default"));
const constants_1 = __importDefault(require("../../constants"));
const types_1 = require("../../../types");
const logger_1 = __importDefault(require("../../../logger"));
const promptTypes = [
    'login',
    'login-id',
    'login-password',
    'login-passwordless',
    'login-email-verification',
    'signup',
    'signup-id',
    'signup-password',
    'phone-identifier-enrollment',
    'phone-identifier-challenge',
    'email-identifier-challenge',
    'reset-password',
    'custom-form',
    'consent',
    'customized-consent',
    'logout',
    'mfa-push',
    'mfa-otp',
    'mfa-voice',
    'mfa-phone',
    'mfa-webauthn',
    'mfa-sms',
    'mfa-email',
    'mfa-recovery-code',
    'mfa',
    'status',
    'device-flow',
    'email-verification',
    'email-otp-challenge',
    'organizations',
    'invitation',
    'common',
    'captcha',
];
const screenTypes = [
    'login',
    'login-id',
    'login-password',
    'login-email-verification',
    'signup',
    'signup-id',
    'signup-password',
    'reset-password-request',
    'reset-password-email',
    'reset-password',
    'reset-password-success',
    'reset-password-error',
    'consent',
    'status',
    'mfa-detect-browser-capabilities',
    'mfa-enroll-result',
    'mfa-login-options',
    'mfa-begin-enroll-options',
    'mfa-otp-enrollment-qr',
    'mfa-otp-enrollment-code',
    'mfa-otp-challenge',
    'mfa-voice-challenge',
    'mfa-sms-challenge',
    'mfa-recovery-code-enrollment',
    'mfa-recovery-code-challenge',
    'mfa-country-codes',
    'mfa-sms-enrollment',
    'mfa-voice-enrollment',
    'mfa-phone-challenge',
    'mfa-phone-enrollment',
    'mfa-webauthn-roaming-enrollment',
    'mfa-webauthn-platform-enrollment',
    'mfa-webauthn-platform-challenge',
    'mfa-webauthn-roaming-challenge',
    'mfa-webauthn-change-key-nickname',
    'mfa-webauthn-enrollment-success',
    'mfa-webauthn-error',
    'mfa-webauthn-not-available-error',
    'mfa-sms-list',
    'mfa-email-challenge',
    'mfa-email-list',
    'mfa-push-welcome',
    'mfa-push-list',
    'mfa-push-enrollment-qr',
    'mfa-push-enrollment-code',
    'mfa-push-success',
    'mfa-push-challenge-push',
    'device-code-activation',
    'device-code-activation-allowed',
    'device-code-activation-denied',
    'device-code-confirmation',
    'email-verification-result',
    'email-otp-challenge',
    'redeem-ticket',
    'organization-selection',
    'accept-invitation',
    'login-passwordless-email-code',
    'login-passwordless-email-link',
    'login-passwordless-sms-otp',
];
const customPartialsPromptTypes = [
    'login',
    'login-id',
    'login-password',
    'login-passwordless',
    'signup',
    'signup-id',
    'signup-password',
];
const customPartialsScreenTypes = [
    'login',
    'login-id',
    'login-password',
    'signup',
    'signup-id',
    'signup-password',
    'login-passwordless-sms-otp',
    'login-passwordless-email-code',
];
const customPartialsInsertionPoints = [
    'form-content-start',
    'form-content-end',
    'form-footer-start',
    'form-footer-end',
    'secondary-actions-start',
    'secondary-actions-end',
];
exports.schema = {
    type: 'object',
    properties: {
        universal_login_experience: {
            type: 'string',
            enum: ['new', 'classic'],
        },
        webauthn_platform_first_factor: {
            type: 'boolean',
        },
        identifier_first: {
            type: 'boolean',
        },
        customText: {
            type: 'object',
            properties: types_1.languages.reduce((acc, language) => (Object.assign(Object.assign({}, acc), { [language]: {
                    type: 'object',
                    properties: promptTypes.reduce((promptAcc, promptType) => (Object.assign(Object.assign({}, promptAcc), { [promptType]: {
                            type: 'object',
                            properties: screenTypes.reduce((screenAcc, screenType) => (Object.assign(Object.assign({}, screenAcc), { [screenType]: {
                                    type: 'object',
                                } })), {}),
                        } })), {}),
                } })), {}),
        },
        partials: {
            type: 'object',
            properties: customPartialsPromptTypes.reduce((acc, customPartialsPromptType) => (Object.assign(Object.assign({}, acc), { [customPartialsPromptType]: {
                    oneOf: [
                        {
                            type: 'object',
                            properties: customPartialsScreenTypes.reduce((screenAcc, customPartialsScreenType) => (Object.assign(Object.assign({}, screenAcc), { [customPartialsScreenType]: {
                                    oneOf: [
                                        {
                                            type: 'object',
                                            properties: customPartialsInsertionPoints.reduce((insertionAcc, customPartialsInsertionPoint) => (Object.assign(Object.assign({}, insertionAcc), { [customPartialsInsertionPoint]: {
                                                    type: 'string',
                                                } })), {}),
                                        },
                                        { type: 'null' },
                                    ],
                                } })), {}),
                        },
                        { type: 'null' },
                    ],
                } })), {}),
        },
        screenRenderers: {
            type: 'array',
            properties: promptTypes.reduce((promptAcc, promptType) => (Object.assign(Object.assign({}, promptAcc), { [promptType]: {
                    type: 'array',
                    properties: screenTypes.reduce((screenAcc, screenType) => (Object.assign(Object.assign({}, screenAcc), { [screenType]: {
                            type: 'string',
                        } })), {}),
                } })), {}),
        },
    },
};
class PromptsHandler extends default_1.default {
    constructor(options) {
        super(Object.assign(Object.assign({}, options), { type: 'prompts' }));
        this.IsFeatureSupported = true;
    }
    objString({ customText, screenRenderers }) {
        let description = 'Prompts settings';
        if (customText) {
            description += ' and prompts custom text';
        }
        if (screenRenderers && screenRenderers.length > 0) {
            description += ' and screen renderers';
        }
        return description;
    }
    getType() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data: promptsSettings } = yield this.client.prompts.get();
            const customText = yield this.getCustomTextSettings();
            const partials = yield this.getCustomPromptsPartials();
            const prompts = Object.assign(Object.assign({}, promptsSettings), { customText,
                partials });
            const includeExperimentalEA = this.config('AUTH0_EXPERIMENTAL_EA') || false;
            if (includeExperimentalEA) {
                try {
                    const screenRenderers = yield this.getPromptScreenSettings();
                    prompts.screenRenderers = screenRenderers;
                }
                catch (error) {
                    logger_1.default.warn(`Unable to fetch screen renderers: ${error}`);
                }
            }
            return prompts;
        });
    }
    getCustomTextSettings() {
        return __awaiter(this, void 0, void 0, function* () {
            const supportedLanguages = yield this.client.tenants
                .getSettings()
                .then(({ data: { enabled_locales } }) => {
                if (enabled_locales === undefined)
                    return []; // In rare cases, private cloud tenants may not have `enabled_locales` defined
                return enabled_locales;
            });
            return this.client.pool
                .addEachTask({
                data: supportedLanguages
                    .map((language) => promptTypes.map((promptType) => ({ promptType, language })))
                    .reduce((acc, val) => acc.concat(val), []) || [],
                generator: ({ promptType, language }) => this.client.prompts
                    .getCustomTextByLanguage({
                    prompt: promptType,
                    language,
                })
                    .then(({ data: customTextData }) => {
                    if ((0, lodash_1.isEmpty)(customTextData))
                        return null;
                    return {
                        language,
                        [promptType]: Object.assign({}, customTextData),
                    };
                }),
            })
                .promise()
                .then((customTextData) => customTextData
                .filter((customTextData) => customTextData !== null)
                .reduce((acc, customTextItem) => {
                if ((customTextItem === null || customTextItem === void 0 ? void 0 : customTextItem.language) === undefined)
                    return acc;
                const { language } = customTextItem, customTextSettings = __rest(customTextItem, ["language"]);
                return Object.assign(Object.assign({}, acc), { [language]: acc[language]
                        ? Object.assign(Object.assign({}, acc[language]), customTextSettings) : Object.assign({}, customTextSettings) });
            }, {}));
        });
    }
    /**
     * Error handler wrapper.
     */
    withErrorHandling(callback) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            try {
                return yield callback();
            }
            catch (error) {
                // Extract error data
                if (error && (error === null || error === void 0 ? void 0 : error.statusCode) === 403) {
                    logger_1.default.warn('Partial Prompts feature is not supported for the tenant');
                    this.IsFeatureSupported = false;
                    return null;
                }
                if (error &&
                    (error === null || error === void 0 ? void 0 : error.statusCode) === 400 &&
                    ((_a = error.message) === null || _a === void 0 ? void 0 : _a.includes('feature requires at least one custom domain'))) {
                    logger_1.default.warn('Partial Prompts feature requires at least one custom domain to be configured for the tenant');
                    this.IsFeatureSupported = false;
                    return null;
                }
                if (error && error.statusCode === 429) {
                    logger_1.default.error(`The global rate limit has been exceeded, resulting in a ${error.statusCode} error. ${error.message}. Although this is an error, it is not blocking the pipeline.`);
                    return null;
                }
                throw error;
            }
        });
    }
    getCustomPartial(_a) {
        return __awaiter(this, arguments, void 0, function* ({ prompt, }) {
            if (!this.IsFeatureSupported)
                return {};
            return this.withErrorHandling(() => __awaiter(this, void 0, void 0, function* () { return this.client.prompts.getPartials({ prompt }); }));
        });
    }
    getCustomPromptsPartials() {
        return __awaiter(this, void 0, void 0, function* () {
            const partialsDataWithNulls = yield this.client.pool
                .addEachTask({
                data: customPartialsPromptTypes,
                generator: (promptType) => this.getCustomPartial({
                    prompt: promptType,
                }).then((partialsData) => {
                    if ((0, lodash_1.isEmpty)(partialsData === null || partialsData === void 0 ? void 0 : partialsData.data))
                        return null;
                    return { promptType, partialsData: partialsData.data };
                }),
            })
                .promise();
            const validPartialsData = partialsDataWithNulls.filter(Boolean);
            return validPartialsData.reduce((acc, partialData) => {
                if (partialData) {
                    const { promptType, partialsData } = partialData;
                    acc[promptType] = partialsData;
                }
                return acc;
            }, {});
        });
    }
    getPromptScreenSettings() {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('Loading Prompt Screen Renderers. This may take a while...');
            // Create combinations of prompt and screens
            const promptScreenCombinations = Object.entries(constants_1.default.PROMPT_SCREEN_MAPPINGS).flatMap(([promptType, screens]) => screens.map((screen) => ({
                promptName: promptType,
                screenName: screen,
            })));
            const renderSettings = yield this.client.pool
                .addEachTask({
                data: promptScreenCombinations,
                generator: ({ promptName, screenName }) => this.client.prompts
                    .getRendering({
                    prompt: promptName,
                    screen: screenName,
                })
                    .then(({ data: renderingSettings }) => {
                    if ((0, lodash_1.isEmpty)(renderingSettings))
                        return null;
                    return renderingSettings;
                }),
            })
                .promise();
            const customRenderingRes = renderSettings.filter((item) => item !== null);
            return customRenderingRes;
        });
    }
    processChanges(assets) {
        return __awaiter(this, void 0, void 0, function* () {
            const { prompts } = assets;
            if (!prompts)
                return;
            const { partials, customText, screenRenderers } = prompts, promptSettings = __rest(prompts, ["partials", "customText", "screenRenderers"]);
            if (!(0, lodash_1.isEmpty)(promptSettings)) {
                yield this.client.prompts.update(promptSettings);
            }
            yield this.updateCustomTextSettings(customText);
            yield this.updateCustomPromptsPartials(partials);
            // Update screen renderers
            yield this.updateScreenRenderers(screenRenderers);
            this.updated += 1;
            this.didUpdate(prompts);
        });
    }
    updateCustomTextSettings(customText) {
        return __awaiter(this, void 0, void 0, function* () {
            /*
              Note: deletes are not currently supported
            */
            if (!customText)
                return;
            yield this.client.pool
                .addEachTask({
                data: Object.keys(customText).flatMap((language) => {
                    const languageScreenTypes = customText[language];
                    if (!languageScreenTypes)
                        return [];
                    return Object.keys(languageScreenTypes).map((prompt) => {
                        const body = languageScreenTypes[prompt] || {};
                        return {
                            body,
                            language,
                            prompt,
                        };
                    });
                }),
                generator: ({ prompt, language, body }) => this.client.prompts.updateCustomTextByLanguage({ prompt, language }, body),
            })
                .promise();
        });
    }
    updateCustomPartials(_a) {
        return __awaiter(this, arguments, void 0, function* ({ prompt, body, }) {
            if (!this.IsFeatureSupported)
                return;
            yield this.withErrorHandling(() => __awaiter(this, void 0, void 0, function* () { return this.client.prompts.updatePartials({ prompt }, body); }));
        });
    }
    updateCustomPromptsPartials(partials) {
        return __awaiter(this, void 0, void 0, function* () {
            /*
              Note: deletes are not currently supported
            */
            if (!partials)
                return;
            yield this.client.pool
                .addEachTask({
                data: Object.keys(partials).map((prompt) => {
                    const body = partials[prompt] || {};
                    return {
                        body,
                        prompt,
                    };
                }),
                generator: ({ prompt, body }) => this.updateCustomPartials({ prompt, body }),
            })
                .promise();
        });
    }
    updateScreenRenderer(screenRenderer) {
        return __awaiter(this, void 0, void 0, function* () {
            const { prompt, screen, rendering_mode, tenant } = screenRenderer, updatePrams = __rest(screenRenderer, ["prompt", "screen", "rendering_mode", "tenant"]);
            if (!prompt || !screen)
                return;
            let updatePayload = {};
            if (rendering_mode === auth0_1.PatchRenderingRequestRenderingModeEnum.standard) {
                updatePayload = {
                    rendering_mode,
                };
            }
            else {
                updatePayload = Object.assign(Object.assign({}, updatePrams), { rendering_mode });
            }
            try {
                yield this.client.prompts.updateRendering({
                    prompt: prompt,
                    screen: screen,
                }, Object.assign({}, updatePayload));
            }
            catch (error) {
                const errorMessage = `Problem updating ${this.type} screen renderers  ${prompt}:${screen}\n${error}`;
                logger_1.default.error(errorMessage);
                throw new Error(errorMessage);
            }
        });
    }
    updateScreenRenderers(screenRenderers) {
        return __awaiter(this, void 0, void 0, function* () {
            if ((0, lodash_1.isEmpty)(screenRenderers) || !screenRenderers)
                return;
            yield this.client.pool
                .addEachTask({
                data: screenRenderers,
                generator: (updateParams) => this.updateScreenRenderer(updateParams),
            })
                .promise();
        });
    }
}
exports.default = PromptsHandler;
//# sourceMappingURL=prompts.js.map