import { GetSelfServiceProfileCustomTextLanguageEnum, GetSelfServiceProfileCustomTextPageEnum, SsProfile } from 'auth0';
import { Asset, Assets, CalculatedChanges } from '../../../types';
import DefaultAPIHandler from './default';
type customTextType = {
    [GetSelfServiceProfileCustomTextLanguageEnum.en]: {
        [GetSelfServiceProfileCustomTextPageEnum.get_started]: Object;
    };
};
export type SsProfileWithCustomText = Omit<SsProfile, 'created_at' | 'updated_at'> & {
    customText?: customTextType;
};
export declare const schema: {
    type: string;
    items: {
        type: string;
        properties: {
            id: {
                type: string;
            };
            name: {
                type: string;
            };
            description: {
                type: string;
            };
            user_attributes: {
                type: string;
                items: {
                    type: string;
                    properties: {
                        name: {
                            type: string;
                        };
                        description: {
                            type: string;
                        };
                        is_optional: {
                            type: string;
                        };
                    };
                };
            };
            branding: {
                type: string;
                properties: {
                    logo_url: {
                        type: string;
                    };
                    colors: {
                        type: string;
                        properties: {
                            primary: {
                                type: string;
                            };
                        };
                        required: string[];
                    };
                };
            };
            customText: {
                type: string;
                properties: {
                    en: {
                        type: string;
                        properties: {
                            "get-started": {
                                type: string;
                            };
                        };
                    };
                };
            };
        };
        required: string[];
    };
};
export default class SelfServiceProfileHandler extends DefaultAPIHandler {
    existing: SsProfileWithCustomText[];
    constructor(config: DefaultAPIHandler);
    getType(): Promise<SsProfileWithCustomText[]>;
    processChanges(assets: Assets): Promise<void>;
    updateCustomText(ssProfileId: string, customText: customTextType): Promise<void>;
    createSelfServiceProfiles(creates: CalculatedChanges['create']): Promise<void>;
    createSelfServiceProfile(profile: SsProfileWithCustomText): Promise<Asset>;
    updateSelfServiceProfiles(updates: CalculatedChanges['update']): Promise<void>;
    updateSelfServiceProfile(profile: SsProfileWithCustomText): Promise<Asset>;
    deleteSelfServiceProfiles(deletes: CalculatedChanges['del']): Promise<void>;
    deleteSelfServiceProfile(profile: SsProfileWithCustomText): Promise<void>;
}
export {};
