"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.schema = void 0;
const auth0_1 = require("auth0");
const lodash_1 = require("lodash");
const logger_1 = __importDefault(require("../../../logger"));
const default_1 = __importDefault(require("./default"));
const calculateChanges_1 = require("../../calculateChanges");
const client_1 = require("../client");
exports.schema = {
    type: 'array',
    items: {
        type: 'object',
        properties: {
            id: {
                type: 'string',
            },
            name: {
                type: 'string',
            },
            description: {
                type: 'string',
            },
            user_attributes: {
                type: 'array',
                items: {
                    type: 'object',
                    properties: {
                        name: {
                            type: 'string',
                        },
                        description: {
                            type: 'string',
                        },
                        is_optional: {
                            type: 'boolean',
                        },
                    },
                },
            },
            branding: {
                type: 'object',
                properties: {
                    logo_url: {
                        type: 'string',
                    },
                    colors: {
                        type: 'object',
                        properties: {
                            primary: {
                                type: 'string',
                            },
                        },
                        required: ['primary'],
                    },
                },
            },
            customText: {
                type: 'object',
                properties: {
                    [auth0_1.GetSelfServiceProfileCustomTextLanguageEnum.en]: {
                        type: 'object',
                        properties: {
                            [auth0_1.GetSelfServiceProfileCustomTextPageEnum.get_started]: {
                                type: 'object',
                            },
                        },
                    },
                },
            },
        },
        required: ['name'],
    },
};
class SelfServiceProfileHandler extends default_1.default {
    constructor(config) {
        super(Object.assign(Object.assign({}, config), { type: 'selfServiceProfiles', id: 'id', stripCreateFields: ['created_at', 'updated_at'], stripUpdateFields: ['created_at', 'updated_at'] }));
    }
    getType() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.existing)
                return this.existing;
            const selfServiceProfiles = yield (0, client_1.paginate)(this.client.selfServiceProfiles.getAll, {
                paginate: true,
                include_totals: true,
                is_global: false,
            });
            const selfServiceProfileWithCustomText = yield Promise.all(selfServiceProfiles.map((sp) => __awaiter(this, void 0, void 0, function* () {
                /**
                 * Fetches the custom text for the "get_started" in "en" page of a self-service profile.
                 */
                const { data: getStartedText } = yield this.client.selfServiceProfiles.getCustomText({
                    id: sp.id,
                    language: auth0_1.GetSelfServiceProfileCustomTextLanguageEnum.en,
                    page: auth0_1.GetSelfServiceProfileCustomTextPageEnum.get_started,
                });
                if (!(0, lodash_1.isEmpty)(getStartedText)) {
                    const customText = {
                        [auth0_1.GetSelfServiceProfileCustomTextLanguageEnum.en]: {
                            [auth0_1.GetSelfServiceProfileCustomTextPageEnum.get_started]: getStartedText,
                        },
                    };
                    return Object.assign(Object.assign({}, sp), { customText });
                }
                return sp;
            })));
            this.existing = selfServiceProfileWithCustomText;
            return this.existing;
        });
    }
    processChanges(assets) {
        return __awaiter(this, void 0, void 0, function* () {
            const { selfServiceProfiles } = assets;
            // Do nothing if not set
            if (!selfServiceProfiles)
                return;
            // Gets SsProfileWithCustomText from destination tenant
            const existing = yield this.getType();
            const changes = (0, calculateChanges_1.calculateChanges)({
                handler: this,
                assets: selfServiceProfiles,
                existing,
                identifiers: this.identifiers,
                allowDelete: !!this.config('AUTH0_ALLOW_DELETE'),
            });
            logger_1.default.debug(`Start processChanges for selfServiceProfiles [delete:${changes.del.length}] [update:${changes.update.length}], [create:${changes.create.length}]`);
            const myChanges = [
                { del: changes.del },
                { create: changes.create },
                { update: changes.update },
            ];
            yield Promise.all(myChanges.map((change) => __awaiter(this, void 0, void 0, function* () {
                switch (true) {
                    case change.del && change.del.length > 0:
                        yield this.deleteSelfServiceProfiles(change.del || []);
                        break;
                    case change.create && change.create.length > 0:
                        yield this.createSelfServiceProfiles(changes.create);
                        break;
                    case change.update && change.update.length > 0:
                        if (change.update)
                            yield this.updateSelfServiceProfiles(change.update);
                        break;
                    default:
                        break;
                }
            })));
        });
    }
    updateCustomText(ssProfileId, customText) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.client.selfServiceProfiles.updateCustomText({
                    id: ssProfileId,
                    language: auth0_1.GetSelfServiceProfileCustomTextLanguageEnum.en,
                    page: auth0_1.GetSelfServiceProfileCustomTextPageEnum.get_started,
                }, Object.assign({}, customText[auth0_1.GetSelfServiceProfileCustomTextLanguageEnum.en][auth0_1.GetSelfServiceProfileCustomTextPageEnum.get_started]));
                logger_1.default.debug(`Updated custom text for ${this.type} ${ssProfileId}`);
            }
            catch (err) {
                logger_1.default.error(`Problem updating custom text for ${this.type} ${ssProfileId}\n${err}`);
                throw new Error(`Problem updating custom text for ${this.type} ${ssProfileId}\n${err}`);
            }
        });
    }
    createSelfServiceProfiles(creates) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.pool
                .addEachTask({
                data: creates || [],
                generator: (item) => this.createSelfServiceProfile(item)
                    .then((data) => {
                    this.didCreate(data);
                    this.created += 1;
                })
                    .catch((err) => {
                    throw new Error(`Problem creating ${this.type} ${this.objString(item)}\n${err}`);
                }),
            })
                .promise();
        });
    }
    createSelfServiceProfile(profile) {
        return __awaiter(this, void 0, void 0, function* () {
            const { customText } = profile, ssProfile = __rest(profile, ["customText"]);
            const { data: created } = yield this.client.selfServiceProfiles.create(ssProfile);
            if (!(0, lodash_1.isEmpty)(customText)) {
                yield this.updateCustomText(created.id, customText);
            }
            return created;
        });
    }
    updateSelfServiceProfiles(updates) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.pool
                .addEachTask({
                data: updates || [],
                generator: (item) => this.updateSelfServiceProfile(item)
                    .then((data) => {
                    this.didUpdate(data);
                    this.updated += 1;
                })
                    .catch((err) => {
                    throw new Error(`Problem updating ${this.type} ${this.objString(item)}\n${err}`);
                }),
            })
                .promise();
        });
    }
    updateSelfServiceProfile(profile) {
        return __awaiter(this, void 0, void 0, function* () {
            const { customText, id } = profile, ssProfile = __rest(profile, ["customText", "id"]);
            const { data: updated } = yield this.client.selfServiceProfiles.update({ id }, ssProfile);
            if (!(0, lodash_1.isEmpty)(customText)) {
                yield this.updateCustomText(updated.id, customText);
            }
            return updated;
        });
    }
    deleteSelfServiceProfiles(deletes) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.config('AUTH0_ALLOW_DELETE') === 'true' ||
                this.config('AUTH0_ALLOW_DELETE') === true) {
                yield this.client.pool
                    .addEachTask({
                    data: deletes || [],
                    generator: (item) => this.deleteSelfServiceProfile(item)
                        .then(() => {
                        this.didDelete(item);
                        this.deleted += 1;
                    })
                        .catch((err) => {
                        throw new Error(`Problem deleting ${this.type} ${this.objString(item)}\n${err}`);
                    }),
                })
                    .promise();
            }
            else {
                logger_1.default.warn(`Detected the following selfServiceProfile should be deleted. Doing so may be destructive.\nYou can enable deletes by setting 'AUTH0_ALLOW_DELETE' to true in the config
            \n${deletes.map((i) => this.objString(i)).join('\n')}`);
            }
        });
    }
    deleteSelfServiceProfile(profile) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.selfServiceProfiles.delete({ id: profile.id });
        });
    }
}
exports.default = SelfServiceProfileHandler;
//# sourceMappingURL=selfServiceProfiles.js.map