import { Auth0 } from './tools';
import { Asset, Assets, Config, KeywordMappings } from './types';
export declare function isDirectory(filePath: string): boolean;
export declare function isFile(filePath: string): boolean;
export declare function getFiles(folder: string, exts: string[]): string[];
export declare function loadJSON(file: string, opts?: {
    disableKeywordReplacement: boolean;
    mappings: KeywordMappings;
}): any;
export declare function dumpJSON(file: string, mappings: {
    [key: string]: any;
}): void;
export declare function existsMustBeDir(folder: string): boolean;
export declare function toConfigFn(data: Config): (arg0: keyof Config) => any;
export declare function stripIdentifiers(auth0: Auth0, assets: Assets): {
    actions?: import("./tools/auth0/handlers/actions").Action[] | null | undefined;
    attackProtection?: Asset | null | undefined;
    branding?: (Asset & {
        templates?: {
            template: string;
            body: string;
        }[] | null;
    }) | null | undefined;
    phoneProviders?: import("auth0").GetBrandingPhoneProviders200ResponseProvidersInner[] | null | undefined;
    clients?: import("./tools/auth0/handlers/clients").Client[] | null | undefined;
    clientGrants?: import("./tools/auth0/handlers/clientGrants").ClientGrant[] | null | undefined;
    connections?: Asset[] | null | undefined;
    customDomains?: import("auth0").CustomDomain[] | null | undefined;
    databases?: Asset[] | null | undefined;
    emailProvider?: Asset | null | undefined;
    emailTemplates?: Asset[] | null | undefined;
    guardianFactorProviders?: Asset[] | null | undefined;
    guardianFactors?: Asset[] | null | undefined;
    guardianFactorTemplates?: Asset[] | null | undefined;
    guardianPhoneFactorMessageTypes?: {
        message_types: Asset[];
    } | null | undefined;
    guardianPhoneFactorSelectedProvider?: Asset | null | undefined;
    guardianPolicies?: {
        policies: string[];
    } | null | undefined;
    hooks?: Asset[] | null | undefined;
    logStreams?: import("./tools/auth0/handlers/logStreams").LogStream[] | null | undefined;
    organizations?: Asset[] | null | undefined;
    pages?: import("./tools/auth0/handlers/pages").Page[] | null | undefined;
    prompts?: Partial<import("./tools/auth0/handlers/prompts").PromptSettings & {
        customText: import("./tools/auth0/handlers/prompts").AllPromptsByLanguage;
        partials: import("./tools/auth0/handlers/prompts").CustomPromptPartials;
        screenRenderers?: import("./tools/auth0/handlers/prompts").ScreenRenderer[];
    }> | null | undefined;
    resourceServers?: import("auth0").ResourceServer[] | null | undefined;
    roles?: Asset[] | null | undefined;
    rules?: Asset[] | null | undefined;
    rulesConfigs?: Asset[] | null | undefined;
    tenant?: import("auth0").TenantSettings | null | undefined;
    triggers?: Asset[] | null | undefined;
    exclude?: {
        [key: string]: string[];
    } | undefined;
    clientsOrig?: Asset[] | null | undefined;
    themes?: import("auth0").PostBrandingTheme200Response[] | null | undefined;
    forms?: import("./tools/auth0/handlers/forms").Form[] | null | undefined;
    flows?: import("./tools/auth0/handlers/flows").Flow[] | null | undefined;
    flowVaultConnections?: import("./tools/auth0/handlers/flowVaultConnections").FlowVaultConnection[] | null | undefined;
    selfServiceProfiles?: import("./tools/auth0/handlers/selfServiceProfiles").SsProfileWithCustomText[] | null | undefined;
    networkACLs?: import("auth0").GetNetworkAclsById200Response[] | null | undefined;
};
export declare function sanitize(str: string): string;
type ImportantFields = {
    name: string | null;
    client_id: string | null;
    audience: string | null;
    template: string | null;
    identifier: string | null;
    strategy: string | null;
    script: string | null;
    stage: string | null;
    id: string | null;
};
export declare function formatResults(item: any): Partial<ImportantFields>;
export declare function recordsSorter(a: Partial<ImportantFields>, b: Partial<ImportantFields>): number;
export declare function clearTenantFlags(tenant: Asset): void;
export declare function ensureProp(obj: Asset, props: string): void;
export declare function clearClientArrays(client: Asset): Asset;
export declare function convertClientIdToName(clientId: string, knownClients?: Asset[]): string;
export declare function mapClientID2NameSorted(enabledClients: string[], knownClients: Asset[]): string[];
export declare function nomalizedYAMLPath(filePath: string): string[];
export declare const findKeyPathWithValue: (obj: any, findKey: string, parentPath?: string) => {
    path: string;
    value: any;
}[];
/**
 * Encodes a certificate string to Base64 format if it starts with '-----BEGIN CERTIFICATE-----'.
 *
 * @param cert - The certificate string to be encoded.
 * @returns The Base64 encoded certificate string if the input starts with '-----BEGIN CERTIFICATE-----', otherwise returns the original string.
 */
export declare const encodeCertStringToBase64: (cert: string) => string;
export {};
